@@ -18,14 +18,15 @@
     to purchase a commercial license.
 """
 
-__VERSION__ = "1.1.13"
+__VERSION__ = "1.1.18"
 
 from .frame.databundler import DataBundler
-from .frame.experiment import ExperimentViewer, Experiment
+from .frame.experiment import ExperimentViewer, Experiment, globs
 from .frame.logger import Logger
 from .frame.meter import Meter, AvgMeter
 from .frame.params import Params
 from .frame.saver import Saver
 from .frame.trainer import Trainer
 
-from .utils import torch
\ No newline at end of file
+from .frame import callbacks
+from .utils import torch
