@@ -126,7 +126,7 @@ class TrainCallback(BaseCallback):
             self.on_train_epoch_begin(trainer, func, param, *args, **kwargs)
         elif func.__name__ == "train_batch":
             self.on_train_batch_begin(trainer, func, param, *args, **kwargs)
-        elif func.__name__ == "tests":
+        elif func.__name__ == "test":
             self.on_test_begin(trainer, func, param, *args, **kwargs)
         elif func.__name__ == "eval":
             self.on_eval_begin(trainer, func, param, *args, **kwargs)
@@ -153,7 +153,7 @@ class TrainCallback(BaseCallback):
             self.on_train_epoch_end(trainer, func, param, meter, *args, **kwargs)
         elif func.__name__ == "train_batch":
             self.on_train_batch_end(trainer, func, param, meter, *args, **kwargs)
-        elif func.__name__ == "tests":
+        elif func.__name__ == "test":
             self.on_test_end(trainer, func, param, meter, *args, **kwargs)
         elif func.__name__ == "eval":
             self.on_eval_end(trainer, func, param, meter, *args, **kwargs)
@@ -269,15 +269,18 @@ class ModelCheckpoint(TrainCallback):
             item = meter[self.monitor]
             if isinstance(item, AvgItem):
                 item = item.avg
+            if isinstance(item,NoneItem):
+                return
+
             if self.lower:
                 if self.last_val > item:
+                    trainer.logger.info("model imporved from {} to {}".format(self.last_val,item))
                     trainer.save_checkpoint(meter.serialize())
-                    trainer.logger.info("save_checkpoint")
                     self.last_val = item
             else:
                 if self.last_val < item:
+                    trainer.logger.info("model imporved from {} to {}".format(self.last_val,item))
                     trainer.save_checkpoint(meter.serialize())
-                    trainer.logger.info("save_checkpoint")
                     self.last_val = item
 
     def on_test_end(self, trainer: BaseTrainer, func, param: Params, meter: Meter, *args, **kwargs):
