@@ -239,13 +239,13 @@ class BaseTrainer:
     def save_checkpoint(self, extra_info=None, replacement=False):
         state_dict = self.checkpoint_dict()
         fn = self.saver.save_checkpoint(state_dict["_eidx"], state_dict, extra_info, replacement)
-        self.logger.info("save keypoint in {}".format(fn))
+        self.logger.info("save checkpoint in {}".format(fn))
         return fn
 
     def save_model(self, extra_info=None):
         state_dict = self.state_dict()
         fn = self.saver.save_model(self.params.eidx, state_dict, extra_info)
-        self.logger.info("save keypoint in {}".format(fn))
+        self.logger.info("save model in {}".format(fn))
         return fn
 
     def add_callback(self, callback):
